const { registerBlockType } = wp.blocks;
const { Fragment, RawHTML } = wp.element;
const { InspectorControls, InnerBlocks, MediaUpload, MediaUploadCheck } = wp.blockEditor;
const { RangeControl, Button, PanelBody, ToggleControl } = wp.components;

registerBlockType(
	'simple-block-gallery/slider-block',
	{
		title: 'Slider',
		icon: 'video-alt3',
		category: 'simple-block-gallery',
		attributes: {
	        list_images: {
				type: 'string',
				source: 'html'
			},
			image: {
				type: 'array'
			},
			images_ids: {
				type: 'array'
			},
			animation: {
				type: 'number',
				default: 5
			},
		},

		edit ( props ) {

		const {
			attributes: {
				image,
			},
			setAttributes,
		} = props;

		const onUpdateImage = ( image ) => {
			setAttributes( {
				image: image,
				images_ids: List_Ids( image, props ),
				list_images: List_Images( image, props )
			} );
		};

		function List_Ids( image, props ) {
			let j = [];
			for( let i in image ) {
				j.push( image[i].id );
			}
			return j;
		}

		function List_Images( image, props ) {
			let j = '';
			if ( image ) {
				let slide_interval = '';
				for( let k = 0; k < image.length; k++ ) {
					slide_interval += ( 100 / ( image.length - 1 ) ) * k + '%' + '{ left: -' + ( k * 100 ) + '%; } ';
					slide_interval += ( 100 / ( image.length - 1 ) ) * ( k + 1 ) * 0.8 + '%' + '{ left: -' + ( k * 100 ) + '%; } ';
				}
				j += '<style type="text/css">';
				j += '@keyframes slidy' + image[0].id + ' { ' + slide_interval + '}';
				j += 'div#slider' + image[0].id + ' { overflow: hidden; margin: 0 auto; padding: 0; }';
				j += 'div#slider' + image[0].id + ' figure img { width: ' + 100 / image.length + '%;hight:auto; float: left; }';
				j += 'div#slider' + image[0].id + ' figure { position: relative; width: ' + 100 * image.length + '%; margin: 0; left: 0; text-align: left; font-size: 0; animation: ' + ( props.attributes.animation * image.length ) + 's slidy' + image[0].id + ' infinite; }';
				j += '</style>';
				j += '<div id="slider' + image[0].id + '">';
				j += '<figure>';
				for( let i in image ) {
					j += '<img src="' + image[i].url + '">';
				}
				j += '</figure></div>';
			}
			return j;
		}

		props.attributes.list_images = List_Images( props.attributes.image, props );

		const ALLOWED_MEDIA_TYPES = [ 'image' ];

			return [
			<Fragment>
				<RawHTML>{ props.attributes.list_images }</RawHTML>
				<MediaUploadCheck>
					<MediaUpload
						title={ 'Simple Block Gallery Slider Block' }
						onSelect={ onUpdateImage }
						allowedTypes={ ALLOWED_MEDIA_TYPES }
						gallery = { true }
						multiple = { true }
						value={ props.attributes.images_ids }
						render={ ( { open } ) => (
							<Button className={ 'button button-large' }
								onClick={ open }>
								{ ! props.attributes.images_ids ? simpleblockgallery_slider_text.creategallery : simpleblockgallery_slider_text.updategallery }
							</Button>
						) }
					/>
				</MediaUploadCheck>

				<InspectorControls>
				{}
					<PanelBody title = { simpleblockgallery_slider_text.panelmenu } initialOpen = { true }>
						<RangeControl
							label = { simpleblockgallery_slider_text.animation }
							max = { 30 }
							min = { 1 }
							value = { props.attributes.animation }
							onChange = { ( value ) => props.setAttributes( { animation: value } ) }
						/>
					</PanelBody>
				</InspectorControls>
			</Fragment>
			];
		},

		save ( props ) {
			return (
			<Fragment>
                {
					props.attributes.list_images && (
						<RawHTML>{ props.attributes.list_images }</RawHTML>
					)
				}
			</Fragment>
			);
		},

	}

);
