<?php
/**
 * Simple Block Gallery
 *
 * @package    Simple Block Gallery
 * @subpackage SimpleBlockGallery Main Functions
/*
	Copyright (c) 2020- Katsushi Kawamori (email : dodesyoswift312@gmail.com)
	This program is free software; you can redistribute it and/or modify
	it under the terms of the GNU General Public License as published by
	the Free Software Foundation; version 2 of the License.

	This program is distributed in the hope that it will be useful,
	but WITHOUT ANY WARRANTY; without even the implied warranty of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
	GNU General Public License for more details.

	You should have received a copy of the GNU General Public License
	along with this program; if not, write to the Free Software
	Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */

$simpleblockgallery = new SimpleBlockGallery();

/** ==================================================
 * Main Functions
 */
class SimpleBlockGallery {

	/** ==================================================
	 * Construct
	 *
	 * @since 1.00
	 */
	public function __construct() {

		add_filter( 'block_categories', array( $this, 'simple_block_gallery_category' ), 10, 2 );
		add_action( 'init', array( $this, 'masonry_block_init' ) );
		add_action( 'init', array( $this, 'slider_block_init' ) );

	}

	/** ==================================================
	 * Original category for block
	 *
	 * @param array  $categories  categories.
	 * @param object $post  post.
	 * @since 1.00
	 */
	public function simple_block_gallery_category( $categories, $post ) {
		return array_merge(
			$categories,
			array(
				array(
					'slug' => 'simple-block-gallery',
					'title' => 'Simple Block Gallery',
					'icon' => 'images-alt',
				),
			)
		);
	}

	/** ==================================================
	 * Attribute Masonry block
	 *
	 * @since 1.00
	 */
	public function masonry_block_init() {

		$asset_file = include( plugin_dir_path( __DIR__ ) . 'block/dist/masonry/masonry-block.asset.php' );

		wp_register_script(
			'masonry-block',
			plugins_url( 'block/dist/masonry/masonry-block.js', dirname( __FILE__ ) ),
			$asset_file['dependencies'],
			$asset_file['version'],
			true
		);

		wp_localize_script(
			'masonry-block',
			'simpleblockgallery_masonry_text',
			array(
				'panelmenu' => __( 'Settings' ),
				'creategallery' => __( 'Create Gallery' ),
				'updategallery' => __( 'Update gallery' ),
				'space' => __( 'Space', 'simple-block-gallery' ),
				'r_images' => __( 'Rounded Images', 'simple-block-gallery' ),
				'link' => __( 'Link to Media File' ),
				'width' => __( 'Width' ),
			)
		);

		register_block_type(
			'simple-block-gallery/masonry-block',
			array(
				'editor_script'   => 'masonry-block',
				'attributes'      => array(
					'width'    => array(
						'type'    => 'number',
						'default' => 100,
					),
					'padding'  => array(
						'type'    => 'number',
						'default' => 1,
					),
					'r_images' => array(
						'type'    => 'boolean',
						'default' => true,
					),
					'link'     => array(
						'type'    => 'boolean',
						'default' => false,
					),
				),
			)
		);

	}

	/** ==================================================
	 * Attribute Slider block
	 *
	 * @since 1.00
	 */
	public function slider_block_init() {

		$asset_file = include( plugin_dir_path( __DIR__ ) . 'block/dist/slider/slider-block.asset.php' );

		wp_register_script(
			'slider-block',
			plugins_url( 'block/dist/slider/slider-block.js', dirname( __FILE__ ) ),
			$asset_file['dependencies'],
			$asset_file['version'],
			true
		);

		wp_localize_script(
			'slider-block',
			'simpleblockgallery_slider_text',
			array(
				'panelmenu' => __( 'Settings' ),
				'creategallery' => __( 'Create Gallery' ),
				'updategallery' => __( 'Update gallery' ),
				'space' => __( 'Space', 'simple-block-gallery' ),
				'animation' => __( 'Interval', 'simple-block-gallery' ),
			)
		);

		register_block_type(
			'simple-block-gallery/slider-block',
			array(
				'editor_script'   => 'slider-block',
				'attributes'      => array(
					'animation'    => array(
						'type'    => 'number',
						'default' => 30,
					),
				),
			)
		);

	}

}


